@@ -5,8 +5,6 @@ use thiserror::Error;
 
 #[derive(Debug, Error)]
 pub enum KcfgError {
-    #[error("{0} is not a supported shell type")]
-    NotSupportedShellType(String),
     #[error("{0} is not a valid path")]
     InvalidPath(PathBuf),
     #[error("{0} should be a directory")]
