@@ -6,7 +6,7 @@
 
 use crate::app::*;
 use crate::commands::*;
-use clap::Clap;
+use clap::Parser;
 use std::process::exit;
 
 mod app;
